@@ -378,7 +378,7 @@ move_to(room_number)
 			wump_kill();
 			return(1);
 		}
-		if (cave[next_room].has_a_pit)
+		if (cave[next_room].has_a_pit) {
 			if (random() % 12 < 2) {
 				pit_survive();
 				return(0);
@@ -386,6 +386,7 @@ move_to(room_number)
 				pit_kill();
 				return(1);
 			}
+		}
 
 		if (cave[next_room].has_a_bat) {
 			(void)printf(
@@ -421,13 +422,14 @@ shoot(room_list)
 	 */
 	arrow_location = player_loc;
 	for (roomcnt = 1;; ++roomcnt, room_list = NULL) {
-		if (!(p = strtok(room_list, " \t\n")))
+		if (!(p = strtok(room_list, " \t\n"))) {
 			if (roomcnt == 1) {
 				(void)printf(
 			"The arrow falls to the ground at your feet!\n");
 				return(0);
 			} else
 				break;
+		}
 		if (roomcnt > 5) {
 			(void)printf(
 "The arrow wavers in its flight and and can go no further!\n");
